/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "AngelScript", "index.html", [
    [ "Introduction", "index.html", null ],
    [ "Developer manual", "main_topics.html", [
      [ "License", "doc_license.html", [
        [ "AngelCode Scripting Library", "doc_license.html#doc_lic_1", null ]
      ] ],
      [ "Getting started", "doc_start.html", [
        [ "Overview", "doc_overview.html", null ],
        [ "Compile the library", "doc_compile_lib.html", [
          [ "Set compile time options", "doc_compile_lib.html#doc_compile_lib_1", null ],
          [ "Linking with the library", "doc_compile_lib.html#doc_compile_lib_2", [
            [ "1. Include library source files in project", "doc_compile_lib.html#doc_compile_lib_2_1", null ],
            [ "2. Compile a static library and link into project", "doc_compile_lib.html#doc_compile_lib_2_2", null ],
            [ "3. Compile a dynamically loaded library with an import library", "doc_compile_lib.html#doc_compile_lib_2_3", null ],
            [ "4. Load the dynamically loaded library manually", "doc_compile_lib.html#doc_compile_lib_2_4", null ]
          ] ],
          [ "Considerations for specific platforms", "doc_compile_lib.html#doc_compile_platforms", [
            [ "Windows 64bit", "doc_compile_lib.html#doc_compile_win64", null ],
            [ "Microsoft Visual C++", "doc_compile_lib.html#doc_compile_msvc_sdk", null ],
            [ "GNUC based compilers", "doc_compile_lib.html#doc_compile_gnuc", null ],
            [ "Pocket PC with ARM CPU", "doc_compile_lib.html#doc_compile_pocketpc", null ],
            [ "Marmalade", "doc_compile_lib.html#doc_compile_marmalade", null ]
          ] ],
          [ "Size of the library", "doc_compile_lib.html#doc_compile_size", null ]
        ] ],
        [ "Your first script", "doc_hello_world.html", [
          [ "Helper functions", "doc_hello_world.html#doc_hello_world_1", null ]
        ] ],
        [ "Good practices", "doc_good_practice.html", [
          [ "Always check return values for registrations", "doc_good_practice.html#doc_checkretval", null ],
          [ "Use the message callback to receive detailed error messages", "doc_good_practice.html#doc_usemsgcallbck", null ],
          [ "Always verify return value after executing script function", "doc_good_practice.html#doc_checkexceptions", null ]
        ] ]
      ] ],
      [ "Understanding AngelScript", "doc_understanding_as.html", [
        [ "Versions", "doc_versions.html", [
          [ "History", "doc_versions.html#doc_versions_milestones", [
            [ "2003 - Birth and first public release", "doc_versions.html#doc_versions_2003", null ],
            [ "2005 - Version 2, sand box, object handles, script classes, and garbage collection", "doc_versions.html#doc_versions_2005", null ],
            [ "2006 - Script interface", "doc_versions.html#doc_versions_2006", null ],
            [ "2009 - Inheritance, template types, operator overloads, and JIT compilation", "doc_versions.html#doc_versions_2009", null ],
            [ "2010 - Function pointers", "doc_versions.html#doc_versions_2010", null ],
            [ "2011 - Automatic garbage collection and debugging", "doc_versions.html#doc_versions_2011", null ],
            [ "2012 - Namespaces and mixins", "doc_versions.html#doc_versions_2012", null ],
            [ "2013 - Improved template types, delegates, weak references, and initialization lists", "doc_versions.html#doc_versions_2013", null ],
            [ "2014 - Named arguments and auto", "doc_versions.html#doc_versions_2014", null ],
            [ "2015 - Anonymous functions", "doc_versions.html#doc_versions_2015", null ],
            [ "2016 - Child funcdefs", "doc_versions.html#doc_versions_2016", null ],
            [ "2017 - external keyword and anonymous initialization lists", "doc_versions.html#doc_versions_2017", null ],
            [ "2018 - Try-catch statements and explicit constructors", "doc_versions.html#doc_versions_2018", null ],
            [ "2019 - Explicit property keyword", "doc_versions.html#doc_versions_2019", null ]
          ] ]
        ] ],
        [ "Script modules", "doc_module.html", [
          [ "Single module versus multiple modules", "doc_module.html#doc_module_single_vs_multi", null ],
          [ "Exchanging information between modules", "doc_module.html#doc_module_exchange", null ]
        ] ],
        [ "Datatypes in AngelScript and C++", "doc_as_vs_cpp_types.html", [
          [ "Primitives", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_1", null ],
          [ "Strings", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_5", null ],
          [ "Arrays", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_2", null ],
          [ "Object handles", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_3", null ],
          [ "Script classes and interfaces", "doc_as_vs_cpp_types.html#doc_as_vc_cpp_types_5", null ],
          [ "Function pointers", "doc_as_vs_cpp_types.html#doc_as_vc_cpp_types_6", null ],
          [ "Parameter references", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_4", null ]
        ] ],
        [ "Object handles to the application", "doc_obj_handle.html", [
          [ "Managing the reference counter in functions", "doc_obj_handle.html#doc_obj_handle_3", null ],
          [ "Auto handles can make it easier", "doc_obj_handle.html#doc_obj_handle_4", null ]
        ] ],
        [ "Memory management", "doc_memory.html", [
          [ "Overview of the memory management", "doc_memory.html#doc_memory_1", null ],
          [ "Reference counting algorithm", "doc_memory.html#doc_memory_2", null ],
          [ "Garbage collector algorithm", "doc_memory.html#doc_memory_3", null ],
          [ "Memory heap", "doc_memory.html#doc_memory_4", null ]
        ] ]
      ] ],
      [ "Registering the application interface", "doc_register_api_topic.html", [
        [ "What can be registered", "doc_register_api.html", null ],
        [ "Registering a function", "doc_register_func.html", [
          [ "How to get the address of the application function or method", "doc_register_func.html#doc_register_func_1", null ],
          [ "Calling convention", "doc_register_func.html#doc_register_func_2", null ],
          [ "A little on type differences", "doc_register_func.html#doc_register_func_3", null ],
          [ "Virtual inheritance is not supported", "doc_register_func.html#doc_register_func_4", null ]
        ] ],
        [ "Registering global properties", "doc_register_prop.html", null ],
        [ "Registering an object type", "doc_register_type.html", [
          [ "Registering a reference type", "doc_reg_basicref.html", [
            [ "Factory function", "doc_reg_basicref.html#doc_reg_basicref_1", null ],
            [ "Addref and release behaviours", "doc_reg_basicref.html#doc_reg_basicref_2", null ],
            [ "Reference types without reference counting", "doc_reg_basicref.html#doc_reg_nocount", null ],
            [ "List factory function", "doc_reg_basicref.html#doc_reg_basicref_4", null ],
            [ "Registering an uninstantiable reference type", "doc_reg_basicref.html#doc_reg_noinst", null ]
          ] ],
          [ "Registering a value type", "doc_register_val_type.html", [
            [ "Constructor and destructor", "doc_register_val_type.html#doc_reg_val_1", null ],
            [ "Value types and native calling conventions", "doc_register_val_type.html#doc_reg_val_2", [
              [ "For compilers that don't support C++11", "doc_register_val_type.html#doc_reg_val_2_nocpp11", null ]
            ] ],
            [ "List constructor", "doc_register_val_type.html#doc_reg_val_3", null ]
          ] ],
          [ "Registering operator behaviours", "doc_reg_opbeh.html", [
            [ "Operator overloads", "doc_reg_opbeh.html#doc_reg_opbeh_1", null ]
          ] ],
          [ "Registering object methods", "doc_reg_objmeth.html", [
            [ "Composite members", "doc_reg_objmeth.html#doc_reg_objmeth_composite", null ]
          ] ],
          [ "Registering object properties", "doc_reg_objprop.html", [
            [ "Composite members", "doc_reg_objprop.html#doc_reg_objprop_composite", null ],
            [ "Property accessors", "doc_reg_objprop.html#doc_reg_objprop_accessor", null ]
          ] ]
        ] ],
        [ "Advanced application interface", "doc_advanced_api.html", [
          [ "Custom string type", "doc_strings.html", [
            [ "Registering the custom string type", "doc_strings.html#doc_string_register", null ],
            [ "Unicode vs ASCII", "doc_strings.html#doc_strings_1", null ],
            [ "Multiline string literals", "doc_strings.html#doc_string_2", null ],
            [ "Character literals", "doc_strings.html#doc_string_3", null ]
          ] ],
          [ "Custom array type", "doc_arrays.html", null ],
          [ "Garbage collected objects", "doc_gc_object.html", [
            [ "GC support behaviours", "doc_gc_object.html#doc_reg_gcref_1", null ],
            [ "Factory for garbage collection", "doc_gc_object.html#doc_reg_gcref_2", null ],
            [ "Addref and release for garbage collection", "doc_gc_object.html#doc_reg_gcref_3", null ],
            [ "GC behaviours for value types", "doc_gc_object.html#doc_reg_gcref_value", null ],
            [ "Garbage collected objects and multi-threading", "doc_gc_object.html#doc_reg_gcref_4", null ]
          ] ],
          [ "The generic calling convention", "doc_generic.html", [
            [ "Extracting function arguments", "doc_generic.html#doc_generic_1", null ],
            [ "Returning values", "doc_generic.html#doc_generic_2", null ]
          ] ],
          [ "Registering a generic handle type", "doc_adv_generic_handle.html", null ],
          [ "Registering a scoped reference type", "doc_adv_scoped_type.html", null ],
          [ "Registering a single-reference type", "doc_adv_single_ref_type.html", null ],
          [ "Class hierarchies", "doc_adv_class_hierarchy.html", [
            [ "Establishing the relationship", "doc_adv_class_hierarchy.html#doc_adv_class_hierarchy_1", null ],
            [ "Inherited methods and properties", "doc_adv_class_hierarchy.html#doc_adv_class_hierarchy_2", null ]
          ] ],
          [ "The variable parameter type", "doc_adv_var_type.html", [
            [ "Variable conversion operators", "doc_adv_var_type.html#doc_adv_var_type_1", null ]
          ] ],
          [ "Template types", "doc_adv_template.html", [
            [ "Registering the template type", "doc_adv_template.html#doc_adv_template_1", [
              [ "On subtype replacement for template instances", "doc_adv_template.html#doc_adv_template_1_1", null ]
            ] ],
            [ "Validating template instantiations at compile time", "doc_adv_template.html#doc_adv_template_4", null ],
            [ "Template specializations", "doc_adv_template.html#doc_adv_template_2", null ]
          ] ],
          [ "Weak references", "doc_adv_weakref.html", null ],
          [ "C++ exceptions and longjmp", "doc_cpp_exceptions.html", [
            [ "Exceptions", "doc_cpp_exceptions.html#doc_cpp_exceptions_1", null ],
            [ "longjmp", "doc_cpp_exceptions.html#doc_cpp_exceptions_2", null ]
          ] ]
        ] ]
      ] ],
      [ "Compiling scripts", "doc_compile_script.html", [
        [ "Message callback", "doc_compile_script.html#doc_compile_script_msg", null ],
        [ "Loading and compiling scripts", "doc_compile_script.html#doc_compile_script_load", null ]
      ] ],
      [ "Calling a script function", "doc_call_script_func.html", [
        [ "Preparing context and executing the function", "doc_call_script_func.html#doc_call_script_1", null ],
        [ "Passing and returning primitives", "doc_call_script_func.html#doc_call_script_2", null ],
        [ "Passing and returning objects", "doc_call_script_func.html#doc_call_script_3", null ],
        [ "Exception handling", "doc_call_script_func.html#doc_call_script_4", null ]
      ] ],
      [ "Using script classes", "doc_use_script_class.html", [
        [ "Instantiating the script class", "doc_use_script_class.html#doc_use_script_class_1", null ],
        [ "Calling a method on the script class", "doc_use_script_class.html#doc_use_script_class_2", null ],
        [ "Receiving script classes", "doc_use_script_class.html#doc_use_script_class_3", null ],
        [ "Returning script classes", "doc_use_script_class.html#doc_use_script_class_4", null ]
      ] ],
      [ "Funcdefs and script callback functions", "doc_callbacks.html", [
        [ "An example", "doc_callbacks.html#doc_callbacks_example", null ],
        [ "Delegates", "doc_callbacks.html#doc_callbacks_delegate", null ]
      ] ],
      [ "Advanced topics", "doc_advanced.html", [
        [ "Debugging scripts", "doc_debug.html", [
          [ "Setting line breaks", "doc_debug.html#doc_debug_1", null ],
          [ "Viewing the call stack", "doc_debug.html#doc_debug_2", null ],
          [ "Inspecting variables", "doc_debug.html#doc_debug_3", null ],
          [ "Debugging internally executed scripts", "doc_debug.html#doc_debug_4", null ]
        ] ],
        [ "Timeout long running scripts", "doc_adv_timeout.html", [
          [ "With the line callback", "doc_adv_timeout.html#doc_adv_timeout_1", null ],
          [ "With a secondary thread", "doc_adv_timeout.html#doc_adv_timeout_2", null ]
        ] ],
        [ "Garbage collection", "doc_gc.html", [
          [ "Callback for detected circular references", "doc_gc.html#doc_gc_circcallback", null ],
          [ "Garbage collection and multi-threading", "doc_gc.html#doc_gc_threads", null ]
        ] ],
        [ "Multithreading", "doc_adv_multithread.html", [
          [ "Things to think about with a multithreaded environment", "doc_adv_multithread.html#doc_adv_multithread_1", null ],
          [ "Fibers", "doc_adv_multithread.html#doc_adv_fibers", null ]
        ] ],
        [ "Concurrent scripts", "doc_adv_concurrent.html", null ],
        [ "Co-routines", "doc_adv_coroutine.html", null ],
        [ "Import functions", "doc_adv_import.html", null ],
        [ "Dynamic compilations", "doc_adv_dynamic_build.html", [
          [ "On demand builds", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_ondemand", null ],
          [ "Incremental builds", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_incr", null ],
          [ "Hot reloading scripts", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_hot", [
            [ "Things to consider", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_hot_1", null ]
          ] ]
        ] ],
        [ "Pre-compiled byte code", "doc_adv_precompile.html", [
          [ "Things to remember", "doc_adv_precompile.html#doc_adv_precompile_1", null ]
        ] ],
        [ "Fine tuning", "doc_finetuning.html", [
          [ "Cache the functions and types", "doc_finetuning.html#doc_finetuning_1", null ],
          [ "Reuse the context object", "doc_finetuning.html#doc_finetuning_2", [
            [ "Context pool", "doc_finetuning.html#doc_finetuning_2_1", null ],
            [ "Nested calls", "doc_finetuning.html#doc_finetuning_2_2", null ]
          ] ],
          [ "Compile scripts without line cues", "doc_finetuning.html#doc_finetuning_3", null ],
          [ "Disable thread safety", "doc_finetuning.html#doc_finetuning_4", null ],
          [ "Turn off automatic garbage collection", "doc_finetuning.html#doc_finetuning_5", null ],
          [ "Compare native calling convention versus generic calling convention", "doc_finetuning.html#doc_finetuning_6", null ]
        ] ],
        [ "Access masks and exposing different interfaces", "doc_adv_access_mask.html", null ],
        [ "Using namespaces", "doc_adv_namespace.html", [
          [ "Registering the interface with namespaces", "doc_adv_namespace.html#doc_adv_namespace_reg", null ],
          [ "Finding entities in namespaces", "doc_adv_namespace.html#doc_adv_namespace_enum", null ]
        ] ],
        [ "Dynamic configurations", "doc_adv_dynamic_config.html", null ],
        [ "Custom options", "doc_adv_custom_options.html", [
          [ "Registerable types", "doc_adv_custom_options.html#doc_adv_custom_options_reg_types", null ],
          [ "Language modifications", "doc_adv_custom_options.html#doc_adv_custom_options_lang_mod", null ],
          [ "Engine behaviours", "doc_adv_custom_options.html#doc_adv_custom_options_engine", null ]
        ] ],
        [ "Reflection", "doc_adv_reflection.html", [
          [ "Enumerating variables and properties", "doc_adv_reflection.html#doc_adv_reflection_vars", null ],
          [ "Enumerating functions and methods", "doc_adv_reflection.html#doc_adv_reflection_funcs", null ],
          [ "Enumerating types", "doc_adv_reflection.html#doc_adv_reflection_types", null ]
        ] ],
        [ "Inheriting from application registered class", "doc_adv_inheritappclass.html", null ],
        [ "JIT compilation", "doc_adv_jit_topic.html", [
          [ "How to build a JIT compiler", "doc_adv_jit.html", [
            [ "The structure of the JIT function", "doc_adv_jit.html#doc_adv_jit_3", null ],
            [ "Traversing the byte code", "doc_adv_jit.html#doc_adv_jit_2", null ]
          ] ],
          [ "Byte code instructions", "doc_adv_jit_1.html", [
            [ "Object management", "doc_adv_jit_1.html#doc_adv_jit_1_1", null ],
            [ "Math instructions", "doc_adv_jit_1.html#doc_adv_jit_1_2", null ],
            [ "Bitwise instructions", "doc_adv_jit_1.html#doc_adv_jit_1_3", null ],
            [ "Comparisons", "doc_adv_jit_1.html#doc_adv_jit_1_4", null ],
            [ "Type conversions", "doc_adv_jit_1.html#doc_adv_jit_1_5", null ],
            [ "Increment and decrement", "doc_adv_jit_1.html#doc_adv_jit_1_6", null ],
            [ "Flow control", "doc_adv_jit_1.html#doc_adv_jit_1_7", null ],
            [ "Stack and data management", "doc_adv_jit_1.html#doc_adv_jit_1_8", null ],
            [ "Global variables", "doc_adv_jit_1.html#doc_adv_jit_1_9", null ],
            [ "Initialization list management", "doc_adv_jit_1.html#doc_adv_jit_1_10", null ]
          ] ]
        ] ]
      ] ],
      [ "Samples", "doc_samples.html", [
        [ "Tutorial", "doc_samples_tutorial.html", null ],
        [ "Concurrent scripts", "doc_samples_concurrent.html", null ],
        [ "Console", "doc_samples_console.html", null ],
        [ "Co-routines", "doc_samples_corout.html", null ],
        [ "Events", "doc_samples_events.html", null ],
        [ "Include directive", "doc_samples_incl.html", null ],
        [ "Generic compiler", "doc_samples_asbuild.html", null ],
        [ "Game", "doc_samples_game.html", null ],
        [ "Command line runner", "doc_samples_asrun.html", [
          [ "asrun manual", "doc_samples_asrun_manual.html", [
            [ "Usage", "doc_samples_asrun_manual.html#doc_samples_asrun_usage", null ],
            [ "Scripts", "doc_samples_asrun_manual.html#doc_samples_asrun_script", null ],
            [ "How to debug scripts", "doc_samples_asrun_manual.html#doc_samples_asrun_debug", null ]
          ] ]
        ] ]
      ] ],
      [ "Add-ons", "doc_addon.html", [
        [ "Application modules", "doc_addon_application.html", [
          [ "Script builder", "doc_addon_build.html", [
            [ "Public C++ interface", "doc_addon_build.html#doc_addon_build_1", [
              [ "The include callback signature", "doc_addon_build.html#doc_addon_build_1_1", null ],
              [ "The pragma callback signature", "doc_addon_build.html#doc_addon_build_1_2", null ]
            ] ],
            [ "Include directives", "doc_addon_build.html#doc_addon_build_2", null ],
            [ "Conditional programming", "doc_addon_build.html#doc_addon_build_condition", null ],
            [ "Metadata in scripts", "doc_addon_build.html#doc_addon_build_metadata", null ]
          ] ],
          [ "Context manager", "doc_addon_ctxmgr.html", [
            [ "Public C++ interface", "doc_addon_ctxmgr.html#doc_addon_ctxmgr_1", null ],
            [ "Public script interface", "doc_addon_ctxmgr.html#doc_addon_ctxmgr_2", null ]
          ] ],
          [ "Debugger", "doc_addon_debugger.html", [
            [ "Public C++ interface", "doc_addon_debugger.html#doc_addon_debugger_1", null ],
            [ "Example usage", "doc_addon_debugger.html#doc_addon_debugger_2", null ]
          ] ],
          [ "Serializer", "doc_addon_serializer.html", [
            [ "Public C++ interface", "doc_addon_serializer.html#doc_addon_serializer_1", null ],
            [ "Example usage", "doc_addon_serializer.html#doc_addon_serializer_2", null ]
          ] ],
          [ "Helper functions", "doc_addon_helpers.html", [
            [ "Public C++ interface", "doc_addon_helpers.html#doc_addon_helpers_1", null ],
            [ "Example", "doc_addon_helpers.html#doc_addon_helpers_2", null ]
          ] ],
          [ "Automatic wrapper functions", "doc_addon_autowrap.html", [
            [ "Example usage", "doc_addon_autowrap.html#doc_addon_autowrap_1", null ],
            [ "Adding support for more parameters", "doc_addon_autowrap.html#doc_addon_autowrap_2", null ]
          ] ]
        ] ],
        [ "Script extensions", "doc_addon_script.html", [
          [ "string object", "doc_addon_std_string.html", [
            [ "Public C++ interface", "doc_addon_std_string.html#doc_addon_std_string_1", null ],
            [ "Public script interface", "doc_addon_std_string.html#doc_addon_std_string_2", null ]
          ] ],
          [ "array template object", "doc_addon_array.html", [
            [ "Public C++ interface", "doc_addon_array.html#doc_addon_array_1", null ],
            [ "Public script interface", "doc_addon_array.html#doc_addon_array_2", null ],
            [ "C++ example", "doc_addon_array.html#doc_addon_array_4", null ]
          ] ],
          [ "any object", "doc_addon_any.html", [
            [ "Public C++ interface", "doc_addon_any.html#doc_addon_any_1", null ],
            [ "Public script interface", "doc_addon_any.html#doc_addon_any_2", null ],
            [ "Example usage", "doc_addon_any.html#doc_addon_any_3", null ]
          ] ],
          [ "ref object", "doc_addon_handle.html", [
            [ "Public C++ interface", "doc_addon_handle.html#doc_addon_handle_1", null ],
            [ "Public script interface", "doc_addon_handle.html#doc_addon_handle_3", null ],
            [ "Example usage from C++", "doc_addon_handle.html#doc_addon_handle_4", null ]
          ] ],
          [ "weakref object", "doc_addon_weakref.html", [
            [ "Public C++ interface", "doc_addon_weakref.html#doc_addon_weakref_1", null ],
            [ "Public script interface", "doc_addon_weakref.html#doc_addon_weakref_2", null ]
          ] ],
          [ "dictionary object", "doc_addon_dict.html", [
            [ "Public C++ interface", "doc_addon_dict.html#doc_addon_dict_1", null ],
            [ "Public script interface", "doc_addon_dict.html#doc_addon_dict_2", null ],
            [ "Example usage from C++", "doc_addon_dict.html#doc_addon_dict_3", null ]
          ] ],
          [ "file object", "doc_addon_file.html", [
            [ "Public C++ interface", "doc_addon_file.html#doc_addon_file_1", null ],
            [ "Public script interface", "doc_addon_file.html#doc_addon_file_2", null ]
          ] ],
          [ "filesystem object", "doc_addon_filesystem.html", [
            [ "Public C++ interface", "doc_addon_filesystem.html#doc_addon_filesystem_1", null ],
            [ "Public script interface", "doc_addon_filesystem.html#doc_addon_filesystem_2", null ]
          ] ],
          [ "math functions", "doc_addon_math.html", [
            [ "Public script interface", "doc_addon_math.html#doc_addon_math_1", [
              [ "Functions", "doc_addon_math.html#doc_addon_math_funcs", null ],
              [ "The complex type", "doc_addon_math.html#doc_addon_math_complex", null ]
            ] ]
          ] ],
          [ "grid template object", "doc_addon_grid.html", [
            [ "Public C++ interface", "doc_addon_grid.html#doc_addon_grid_1", null ],
            [ "Public script interface", "doc_addon_grid.html#doc_addon_grid_2", null ],
            [ "Example usage in script", "doc_addon_grid.html#doc_addon_grid_3", null ]
          ] ],
          [ "datetime object", "doc_addon_datetime.html", [
            [ "Public C++ interface", "doc_addon_datetime.html#doc_addon_datetime_1", null ],
            [ "Public script interface", "doc_addon_datetime.html#doc_addon_datetime_2", null ]
          ] ],
          [ "Exception routines", "doc_addon_helpers_try.html", [
            [ "Public C++ interface", "doc_addon_helpers_try.html#doc_addon_helpers_try_1", null ],
            [ "Public script interface", "doc_addon_helpers_try.html#doc_add_helpers_try_2", null ]
          ] ]
        ] ]
      ] ]
    ] ],
    [ "The script language", "doc_script.html", [
      [ "Global entities", "doc_script_global.html", [
        [ "Functions", "doc_global_func.html", null ],
        [ "Variables", "doc_global_variable.html", null ],
        [ "Virtual properties", "doc_global_virtprop.html", null ],
        [ "Script classes", "doc_global_class.html", null ],
        [ "Interfaces", "doc_global_interface.html", null ],
        [ "Mixin class", "doc_script_mixin.html", null ],
        [ "Enums", "doc_global_enums.html", null ],
        [ "Funcdefs", "doc_global_funcdef.html", null ],
        [ "Typedefs", "doc_global_typedef.html", null ],
        [ "Namespaces", "doc_global_namespace.html", null ],
        [ "Imports", "doc_global_import.html", null ]
      ] ],
      [ "Statements", "doc_script_statements.html", [
        [ "Variable declarations", "doc_script_statements.html#variable", null ],
        [ "Expression statement", "doc_script_statements.html#expression", null ],
        [ "Conditions: if / if-else / switch-case", "doc_script_statements.html#if", null ],
        [ "Loops: while / do-while / for", "doc_script_statements.html#while", null ],
        [ "Loop control: break / continue", "doc_script_statements.html#break", null ],
        [ "Return statement", "doc_script_statements.html#return", null ],
        [ "Statement blocks", "doc_script_statements.html#block", null ],
        [ "Try-catch blocks", "doc_script_statements.html#try", null ]
      ] ],
      [ "Expressions", "doc_expressions.html", [
        [ "Assignments", "doc_expressions.html#assignment", null ],
        [ "Function call", "doc_expressions.html#function", null ],
        [ "Math operators", "doc_expressions.html#math", null ],
        [ "Bitwise operators", "doc_expressions.html#bits", null ],
        [ "Compound assignments", "doc_expressions.html#compound", null ],
        [ "Logic operators", "doc_expressions.html#logic", null ],
        [ "Equality comparison operators", "doc_expressions.html#equal", null ],
        [ "Relational comparison operators", "doc_expressions.html#relation", null ],
        [ "Identity comparison operators", "doc_expressions.html#identity", null ],
        [ "Increment operators", "doc_expressions.html#increment", null ],
        [ "Indexing operator", "doc_expressions.html#opindex", null ],
        [ "Conditional expression", "doc_expressions.html#condition", null ],
        [ "Member access", "doc_expressions.html#member", null ],
        [ "Handle-of", "doc_expressions.html#handle", null ],
        [ "Parenthesis", "doc_expressions.html#parenthesis", null ],
        [ "Scope resolution", "doc_expressions.html#scope", null ],
        [ "Type conversions", "doc_expressions.html#conversion", null ],
        [ "Anonymous objects", "doc_expressions.html#anonobj", null ]
      ] ],
      [ "Data types", "doc_datatypes.html", [
        [ "Primitives", "doc_datatypes_primitives.html", [
          [ "void", "doc_datatypes_primitives.html#void", null ],
          [ "bool", "doc_datatypes_primitives.html#bool", null ],
          [ "Integer numbers", "doc_datatypes_primitives.html#int", null ],
          [ "Real numbers", "doc_datatypes_primitives.html#real", null ]
        ] ],
        [ "Objects and handles", "doc_datatypes_obj.html", [
          [ "Objects", "doc_datatypes_obj.html#objects", null ],
          [ "Object handles", "doc_datatypes_obj.html#handles", null ]
        ] ],
        [ "Function handles", "doc_datatypes_funcptr.html", [
          [ "Delegates", "doc_datatypes_funcptr.html#doc_datatypes_delegate", null ]
        ] ],
        [ "Strings", "doc_datatypes_strings.html", null ],
        [ "Auto declarations", "doc_datatypes_auto.html", null ]
      ] ],
      [ "Functions", "doc_script_func.html", [
        [ "Function declaration", "doc_script_func_decl.html", null ],
        [ "Parameter references", "doc_script_func_ref.html", null ],
        [ "Return references", "doc_script_func_retref.html", [
          [ "References to global variables are allowed", "doc_script_func_retref.html#doc_script_retref_global", null ],
          [ "References to class members are allowed", "doc_script_func_retref.html#doc_script_refref_member", null ],
          [ "Can't return reference to local variables", "doc_script_func_retref.html#doc_script_retref_local", null ],
          [ "Can't use expressions with deferred parameters", "doc_script_func_retref.html#doc_script_retref_deferred", null ],
          [ "Can't use expressions that rely on local objects", "doc_script_func_retref.html#doc_script_refref_cleanup", null ]
        ] ],
        [ "Function overloading", "doc_script_func_overload.html", null ],
        [ "Default arguments", "doc_script_func_defarg.html", null ],
        [ "Anonymous functions", "doc_script_anonfunc.html", null ]
      ] ],
      [ "Script classes", "doc_script_class.html", [
        [ "Script class overview", "doc_script_class_desc.html", null ],
        [ "Class constructors", "doc_script_class_construct.html", null ],
        [ "Initialization of class members", "doc_script_class_memberinit.html", null ],
        [ "Class destructor", "doc_script_class_destruct.html", null ],
        [ "Class methods", "doc_script_class_methods.html", [
          [ "Const methods", "doc_script_class_methods.html#doc_script_class_const", null ]
        ] ],
        [ "Inheritance and polymorphism", "doc_script_class_inheritance.html", [
          [ "Extra control with final, abstract, and override", "doc_script_class_inheritance.html#doc_script_class_inheritance_2", null ]
        ] ],
        [ "Protected and private class members", "doc_script_class_private.html", null ],
        [ "Operator overloads", "doc_script_class_ops.html", [
          [ "Prefixed unary operators", "doc_script_class_ops.html#doc_script_class_unary_ops", null ],
          [ "Postfixed unary operators", "doc_script_class_ops.html#doc_script_class_unary2_ops", null ],
          [ "Comparison operators", "doc_script_class_ops.html#doc_script_class_cmp_ops", null ],
          [ "Assignment operators", "doc_script_class_ops.html#doc_script_class_assign_ops", null ],
          [ "Binary operators", "doc_script_class_ops.html#doc_script_class_binary_ops", null ],
          [ "Index operators", "doc_script_class_ops.html#doc_script_class_index_op", null ],
          [ "Functor operator", "doc_script_class_ops.html#doc_script_class_call", null ],
          [ "Type conversion operators", "doc_script_class_ops.html#doc_script_class_conv", null ]
        ] ],
        [ "Property accessors", "doc_script_class_prop.html", [
          [ "Indexed property accessors", "doc_script_class_prop.html#doc_script_class_prop_index", null ]
        ] ]
      ] ],
      [ "Object handles", "doc_script_handle.html", [
        [ "General usage", "doc_script_handle.html#doc_script_handle_1", null ],
        [ "Object life times", "doc_script_handle.html#doc_script_handle_2", null ],
        [ "Object relations and polymorphing", "doc_script_handle.html#doc_script_handle_3", null ],
        [ "Const handles", "doc_script_handle.html#doc_script_handle_4", null ]
      ] ],
      [ "Shared script entities", "doc_script_shared.html", [
        [ "How to declare shared entities", "doc_script_shared.html#doc_script_shared_1", null ],
        [ "External shared entities", "doc_script_shared.html#doc_script_shared_external", null ],
        [ "What can be shared", "doc_script_shared.html#doc_script_shared_2", null ]
      ] ],
      [ "Operator precedence", "doc_operator_precedence.html", [
        [ "Unary operators", "doc_operator_precedence.html#unary", null ],
        [ "Binary and ternary operators", "doc_operator_precedence.html#binary", null ]
      ] ],
      [ "Reserved keywords and tokens", "doc_reserved_keywords.html", null ],
      [ "Script language grammar", "doc_script_bnf.html", null ],
      [ "Standard library", "doc_script_stdlib.html", [
        [ "Exception handling", "doc_script_stdlib_exception.html", [
          [ "Functions", "doc_script_stdlib_exception.html#try_func", null ]
        ] ],
        [ "string", "doc_script_stdlib_string.html", [
          [ "Supporting string object and functions", "doc_script_stdlib_string.html#doc_datatypes_strings_addon", [
            [ "Operators", "doc_script_stdlib_string.html#doc_datatypes_strings_addon_ops", null ],
            [ "Methods", "doc_script_stdlib_string.html#doc_datatypes_strings_addon_mthd", null ],
            [ "Functions", "doc_script_stdlib_string.html#doc_datatypes_strings_addon_funcs", null ]
          ] ]
        ] ],
        [ "array", "doc_datatypes_arrays.html", [
          [ "Supporting array object", "doc_datatypes_arrays.html#doc_datatypes_arrays_addon", [
            [ "Operators", "doc_datatypes_arrays.html#doc_datatypes_array_addon_ops", null ],
            [ "Methods", "doc_datatypes_arrays.html#doc_datatypes_array_addon_mthd", null ],
            [ "Script example", "doc_datatypes_arrays.html#doc_datatypes_array_addon_example", null ]
          ] ]
        ] ],
        [ "dictionary", "doc_datatypes_dictionary.html", [
          [ "Supporting dictionary object", "doc_datatypes_dictionary.html#doc_datatypes_dictionary_addon", [
            [ "Operators", "doc_datatypes_dictionary.html#doc_datatypes_dictionary_addon_ops", null ],
            [ "Methods", "doc_datatypes_dictionary.html#doc_datatypes_dictionary_addon_mthd", null ]
          ] ],
          [ "Supporting dictionaryValue object", "doc_datatypes_dictionary.html#doc_datatypes_dictionaryValue_addon", [
            [ "Operators", "doc_datatypes_dictionary.html#doc_datatypes_dictionaryValue_addon_ops", null ]
          ] ]
        ] ],
        [ "ref", "doc_datatypes_ref.html", [
          [ "Supporting ref object", "doc_datatypes_ref.html#doc_datatypes_ref_addon", [
            [ "Operators", "doc_datatypes_ref.html#doc_datatypes_ref_addon_ops", null ]
          ] ]
        ] ],
        [ "weakref", "doc_datatypes_weakref.html", [
          [ "Supporting weakref object", "doc_datatypes_weakref.html#doc_datatypes_weakref_addon", [
            [ "Constructors", "doc_datatypes_weakref.html#doc_datatypes_weakref_addon_construct", null ],
            [ "Operators", "doc_datatypes_weakref.html#doc_datatypes_weakref_addon_ops", null ],
            [ "Methods", "doc_datatypes_weakref.html#doc_datatypes_weakref_addon_mthd", null ]
          ] ]
        ] ],
        [ "datetime", "doc_script_stdlib_datetime.html", [
          [ "Supporting datetime object", "doc_script_stdlib_datetime.html#doc_datatype_datetime_addon", [
            [ "Constructors", "doc_script_stdlib_datetime.html#doc_addon_datetime_2_construct", null ],
            [ "Methods", "doc_script_stdlib_datetime.html#doc_addon_datetime_2_methods", null ],
            [ "Operators", "doc_script_stdlib_datetime.html#doc_addon_datetime_2_ops", null ]
          ] ]
        ] ],
        [ "Co-routines", "doc_script_stdlib_coroutine.html", [
          [ "Functions", "doc_script_stdlib_coroutine.html#doc_script_stdlib_coroutine_1", null ]
        ] ],
        [ "file", "doc_script_stdlib_file.html", [
          [ "Supporting file object", "doc_script_stdlib_file.html#doc_script_stdlib_file_1", [
            [ "Methods", "doc_script_stdlib_file.html#doc_script_stdlib_file_1_1", null ],
            [ "Properties", "doc_script_stdlib_file.html#doc_script_stdlib_file_1_2", null ]
          ] ]
        ] ],
        [ "filesystem", "doc_script_stdlib_filesystem.html", [
          [ "Supporting filesystem object", "doc_script_stdlib_filesystem.html#doc_script_stdlib_filesystem_1", [
            [ "Methods", "doc_script_stdlib_filesystem.html#doc_script_stdlib_filesystem_1_1", null ]
          ] ]
        ] ],
        [ "System functions", "doc_script_stdlib_system.html", [
          [ "Functions", "doc_script_stdlib_system.html#doc_script_stdlib_system_1", null ]
        ] ]
      ] ]
    ] ],
    [ "Todo List", "todo.html", null ]
  ] ]
];

var NAVTREEINDEX =
[
"doc_addon.html",
"doc_global_variable.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';